@@ -15,17 +15,16 @@ sub match {
     my $argv1 = shift // return undef;
 
     state $regex = qr{(?>
-         .+[ ]user[ ]unknown
-        |[#]5[.]1[.]1[ ]bad[ ]address
-        |[<].+[>][ ]not[ ]found
-        |[<].+[@].+[>][.][.][.][ ]blocked[ ]by[ ]
-        |5[.]0[.]0[.][ ]mail[ ]rejected[.]
+         [#]5[.]1[.]1[ ]bad[ ]address
+        |[<][^ ]+[>][ ]not[ ]found
+        |[<][^ ]+[@][^ ]+[>][.][.][.][ ]blocked[ ]by[ ]
         |5[.]1[.]0[ ]address[ ]rejected[.]
-        |adresse[ ]d[ ]au[ ]moins[ ]un[ ]destinataire[ ]invalide.+[a-z]{3}.+(?:416|418)
+        |adresse[ ]d[ ]au[ ]moins[ ]un[ ]destinataire[ ]invalide[.][ ]invalid[ ]recipient[.][0-9a-z_]+41[68]
         |address[ ](?:does[ ]not[ ]exist|unknown)
         |archived[ ]recipient
         |bad[-_ \t]recipient
         |can[']t[ ]accept[ ]user
+        |does[ ]not[ ]exist[.]
         |destination[ ](?:
              addresses[ ]were[ ]unknown
             |server[ ]rejected[ ]recipients
@@ -42,8 +41,8 @@ sub match {
             |an[ ]active[ ]address[ ]at[ ]this[ ]host
             )
         |mailbox[ ](?:
-             .+[ ]does[ ]not[ ]exist
-            |.+[@].+[ ]unavailable
+             [^ ]+[ ]does[ ]not[ ]exist
+            |[^ ]+[@][^ ]+[ ]unavailable
             |does[ ]not[ ]exist
             |invalid
             |is[ ](?:inactive|unavailable)
@@ -51,7 +50,7 @@ sub match {
             |unavailable
             )
         |no[ ](?:
-             [ ].+[ ]in[ ]name[ ]directory
+             [ ][^ ]+[ ]in[ ]name[ ]directory
             |account[ ]by[ ]that[ ]name[ ]here
             |existe[ ](?:dicha[ ]persona|ese[ ]usuario[ ])
             |mail[ ]box[ ]available[ ]for[ ]this[ ]user
@@ -68,7 +67,7 @@ sub match {
                 |user(?:[ ]here)?
                 )
             |thank[ ]you[ ]rejected:[ ]account[ ]unavailable:
-            |valid[ ]recipients[,][ ]bye    # Microsoft
+            |valid[ ]recipients,[ ]bye
             )
         |non[- ]?existent[ ]user
         |not[ ](?:
@@ -76,15 +75,15 @@ sub match {
             |a[ ]local[ ]address
             |email[ ]addresses
             )
-        |rcpt[ ][<].+[>][ ]does[ ]not[ ]exist
+        |rcpt[ ][<][^ ]+[>][ ]does[ ]not[ ]exist
         |recipient[ ]address[ ]rejected[.][ ][(]in[ ]reply[ ]to[ ]rcpt[ ]to[ ]command[)]
-        |rece?ipient[ ](?:
-             .+[ ]was[ ]not[ ]found[ ]in
+        |recipient[ ](?:
+             [^ ]+[ ]was[ ]not[ ]found[ ]in
             |address[ ]rejected:[ ](?:
                  access[ ]denied
                 |invalid[ ]user
-                |user[ ].+[ ]does[ ]not[ ]exist
-                |user[ ]unknown[ ]in[ ].+[ ]table
+                |user[ ][^ ]+[ ]does[ ]not[ ]exist
+                |user[ ]unknown[ ]in[ ][^ ]+[ ]table
                 |unknown[ ]user
                 )
             |does[ ]not[ ]exist(?:[ ]on[ ]this[ ]system)?
@@ -93,9 +92,8 @@ sub match {
             |unknown
             )
         |requested[ ]action[ ]not[ ]taken:[ ]mailbox[ ]unavailable
-        |resolver[.]adr[.]recip(?:ient)notfound # Microsoft
-        |said:[ ]550[-[ ]]5[.]1[.]1[ ].+[ ]user[ ]unknown[ ]
-        |smtp[ ]error[ ]from[ ]remote[ ]mail[ ]server[ ]after[ ]end[ ]of[ ]data:[ ]553.+does[ ]not[ ]exist
+        |resolver[.]adr[.]recipient notfound
+        |said:[ ]550[-[ ]]5[.]1[.]1[ ][^ ]+[ ]user[ ]unknown[ ]
         |sorry,[ ](?:
              user[ ]unknown
             |badrcptto
@@ -111,7 +109,7 @@ sub match {
              address[ ]no[ ]longer[ ]accepts[ ]mail
             |email[ ]address[ ]is[ ]wrong[ ]or[ ]no[ ]longer[ ]valid
             |spectator[ ]does[ ]not[ ]exist
-            |user[ ]doesn[']?t[ ]have[ ]a[ ].+[ ]account
+            |user[ ]doesn[']?t[ ]have[ ]a[ ][^ ]+[ ]account
             )
         |unknown[ ](?:
              e[-]?mail[ ]address
@@ -121,8 +119,8 @@ sub match {
             |user
             )
         |user[ ](?:
-             .+[ ]was[ ]not[ ]found
-            |.+[ ]does[ ]not[ ]exist
+             [^ ]+[ ]was[ ]not[ ]found
+            |[^ ]+[ ]does[ ]not[ ]exist
             |does[ ]not[ ]exist
             |missing[ ]home[ ]directory
             |not[ ](?:active|exist|found|known)
